@@ -1,4 +1,4 @@
-// Copyright (C) 2013 - 2019  Metrum Research Group
+// Copyright (C) 2013 - 2023  Metrum Research Group
 //
 // This file is part of mrgsolve.
 //
@@ -24,11 +24,12 @@
 //#include <boost/shared_ptr.hpp>
 #include "mrgsolv.h"
 #include "LSODA.h"
+#include <deque>
 
 class odeproblem;
 class datarecord;
 typedef std::shared_ptr<datarecord> rec_ptr;
-typedef std::vector<rec_ptr> reclist;
+typedef std::deque<rec_ptr> reclist;
 
 #define NEWREC std::make_shared<datarecord>
 
@@ -46,7 +47,7 @@ public:
              int pos_, double id_);   
   
   //! short event constructor
-  datarecord(short int cmt_, int evid_, double amt_, double time_, double rate_);
+  datarecord(short int cmt_, int evid_, double amt_, double time_, double rate_, double fn_);
   
   ~datarecord();
   
@@ -76,7 +77,7 @@ public:
   double rate(){return Rate;}
   void rate(double value) {Rate = value;}
   
-  double dur(double b);
+  double dur();
   
   void addl(int addl_){Addl = std::max(0,addl_);}
   unsigned int addl(){return Addl;}
@@ -87,13 +88,16 @@ public:
   void ii(double ii_){Ii = ii_;}
   double ii(){return Ii;}
   
-  void schedule(std::vector<rec_ptr>& thisi, double maxtime, bool put_ev_first, 
-                const unsigned int maxpos, double Fn);
+  double fn(){return Fn;}
+  void fn(double fn_){Fn = fn_;}
+  
+  void schedule(reclist& thisi, double maxtime, bool put_ev_first, 
+                const unsigned int maxpos, double lagt);
   void implement(odeproblem* prob);
   void steady_zero(odeproblem* prob, LSODA& solver);
   void steady_infusion(odeproblem* prob,reclist& thisi,LSODA& solver);
   void steady_bolus(odeproblem* prob,LSODA& solver);
-  void steady(odeproblem* prob, reclist& thisi,double Fn,LSODA& solver);
+  void steady(odeproblem* prob, reclist& thisi,LSODA& solver);
   
   bool infusion(){return (Evid==1 || Evid==4 || Evid==5) && (Rate > 0);}
   bool int_infusion(){return (Evid==1 || Evid==4 || Evid==5) && (Rate > 0) && (Amt > 0);}
@@ -112,26 +116,32 @@ public:
   
   void phantom_rec() {Output=false; Fromdata=false;}
   bool is_phantom() {return !Output && !Fromdata;}
-
-  double Time; ///< record time
-  double Id; ///< record ID value
+  bool is_lagged() {return Lagged;}
+  void lagged() {Lagged = true;}
+  
   int Pos; ///< record position number
   unsigned short int Evid; ///< record event ID
-  bool Output; ///< should this record be included in output?
-  bool Fromdata; ///< is this record from the original data set?
+  unsigned short int Ss; ///< record steady-state indicator
   short int Cmt; ///< record compartment number
   unsigned int Addl; ///< number of additional doses
-  unsigned short int Ss; ///< record steady-state indicator
+  
+  double Time; ///< record time
+  double Id; ///< record ID value
   double Amt; ///< record dosing amount value
   double Rate; ///< record infusion rate value
   double Ii; ///< record inter-dose interval value
-  bool Armed; ///< only armed records are actually executed
+  double Fn; ///< record bioavailability
   
+  bool Output; ///< should this record be included in output?
+  bool Fromdata; ///< is this record from the original data set?
+  bool Lagged; ///< this record was added as result of ALAG
+  bool Armed; ///< only armed records are actually executed
 };
 
 
 bool CompByTimePosRec(const rec_ptr& a, const rec_ptr& b);
-bool CompEqual(const reclist& a, double time, unsigned int evid, int cmt);
+bool CompEqual(const reclist& a, double time, unsigned int evid, int cmt, 
+               double amt);
 
 /** 
  * @brief Functor for sorting data records in <code>reclist</code>. 
@@ -151,4 +161,7 @@ struct CompRec {
   }
 };
 
+void insert_record(reclist& thisi, const size_t start, rec_ptr& rec, 
+                   const bool put_ev_first);
+
 #endif
